//*****************************************************************************************
//    Touch Memory
//*****************************************************************************************
//    "1"

void inp(void)
{
    PORTD   = 0x00;     // 0000 0000
    DDRD    = 0xF0;     // 1111 0000
}
//*****************************************************************************************
//    "0"

void out(void)
{
    PORTD   = 0x00;     // 0000 0000
    DDRD    = 0xF4;     // 1111 0100
}
//*****************************************************************************************
//    Touch Memory   

void ROM_33(void)
{
	static unsigned char rrom, rep;
    rrom = 0x33;
    rep = 8;
RD_B:
    out();
    if (rrom & 0x01)
        goto RD_1;
    __delay_cycles(220);			//     
    goto RD_2;
RD_1:
    __delay_cycles(13);
    inp();
    __delay_cycles(220);			//     
    goto RD_3;
RD_4:
    __delay_cycles(20);
    goto RD_B;
RD_2:
    inp();
RD_3:
	rrom >>= 1;
	if (--rep)
        goto RD_4;
    __delay_cycles(220);
}
//*****************************************************************************************
//      Touch Memory 8 

void rd_data_ROM(void)
{
	static unsigned char a, rep, byte_rom;

    for (a = 0; a < 8; a ++){
        for (rep = 0; rep < 8; rep ++){
            out();
            __delay_cycles(13);
            inp();
            __delay_cycles(50);
            if (!(PIND & 0x04))
                byte_rom &= 0x7F;
            else
                byte_rom |= 0x80;
            if (rep < 7)
                byte_rom >>= 1;
            __delay_cycles(220);
        }
        data_ROM[a] = byte_rom;
    }
}
//*****************************************************************************************
//   CRC
//   0x01, 0x09, 0xC8, 0x26, 0x0B, 0x00, 0x00  0x0F
//    0x01, 0x09, 0xC8, 0x26, 0x0B, 0x00, 0x00, 0x0F  0x00
// 0x01 -    Touch Memory,
// 0x09, 0xC8, 0x26, 0x0B, 0x00, 0x00 - 48   
// 0x0F - 

// 0F		 01	 
// 00000B26C809  

calc_CRC(void)
{
    static unsigned char a, b, crc, byte_crc, temp_crc;

	crc = 0;
    for (b = 0; b < 8; b++){
        byte_crc = data_ROM[b];
        for (a = 0; a <8; a ++){
            temp_crc = byte_crc;
            temp_crc ^= crc;
            if (temp_crc & 0x01){
                crc ^= 0x18;
                crc >>= 1;
                crc |= 0x80;
            }
            else
                crc >>= 1;
            byte_crc >>= 1;
        }
    }
        return crc;
}
//*****************************************************************************************
//   1  2

void chec_data_TM(void)
{
    static unsigned char a;

	chec_TM = 1;
    for (a = 0; a <8; a ++){
        if (data_ROM[a] != tm_manag[a])
            chec_TM = 0;
    }
	if (chec_TM == 1)
		return;

	chec_TM = 2;
	for (a = 0; a <8; a ++){
		if (data_ROM[a] != tm_oper[a])
			chec_TM = 0;
	}
}
//*****************************************************************************************
//     Touch Memory        CRC

void TM_line(void)
{
	_CLI();
    _WDR();

    inp();
    __delay_cycles(1100);// 1066
    out();
    __delay_cycles(1800);// 1666
	inp();
    __delay_cycles(50);
    if (!(PIND & 0x04))
        goto INI_2;
    __delay_cycles(220);
    if (PIND & 0x04)
        goto INI_2;
    __delay_cycles(1100);// 1066
    if (!(PIND & 0x04))
        goto INI_2;
	
    ROM_33();
    rd_data_ROM();
    if (calc_CRC())
        goto INI_2;

    chec_data_TM();

	//    1
    if ((chec_TM == 1) && (menu_flag != KEY_MANAG)
		&& (menu_flag != KEY_OPER)){
        clean_screen();
		key_1();
		chec_TM = 0;
        touch = 0;
        menu_flag = NONE_MENU;
        cursor_flag = 0;
        p = 0;
        delay_c(2);
        clean_screen();
		menu_simbol();
        goto INI_2;
	}
	
	//    2
    if ((chec_TM == 2) && (menu_flag != KEY_MANAG)
		&& (menu_flag != KEY_OPER)){
        clean_screen();
		key_2();
        chec_TM = 0;
        touch = 0;
        menu_flag = NONE_MENU;
        cursor_flag = 0;
        p = 0;
        delay_c(2);
        clean_screen();
		menu_simbol();
		}
INI_2:
    out();
	_SEI();
}
//*****************************************************************************************
void TM_write_manag(void)
{
    _WDR();

    inp();
    __delay_cycles(1100);// 1066
    out();
    __delay_cycles(1800);// 1666
	inp();
    __delay_cycles(50);
    if (!(PIND & 0x04))
        goto INI_3;
    __delay_cycles(220);
    if (PIND & 0x04)
        goto INI_3;
    __delay_cycles(1100);// 1066
    if (!(PIND & 0x04))
        goto INI_3;
	
    ROM_33();
    rd_data_ROM();
    if (calc_CRC())
        goto INI_3;
	p_b = &data_ROM[0];
	write_FM25640(0, 0);
	//	write_TM_manag();
	_CLI();
	clean_screen();
	write_end_manag();
	_SEI();

INI_3:
    out();
}
//*****************************************************************************************
void TM_write_oper(void)
{
    _WDR();

    inp();
    __delay_cycles(1100);// 1066
    out();
    __delay_cycles(1800);// 1666
	inp();
    __delay_cycles(50);
    if (!(PIND & 0x04))
        goto INI_3;
    __delay_cycles(220);
    if (PIND & 0x04)
        goto INI_3;
    __delay_cycles(1100);// 1066
    if (!(PIND & 0x04))
        goto INI_3;
	
    ROM_33();
    rd_data_ROM();
    if (calc_CRC())
        goto INI_3;
	p_b = &data_ROM[0];
	write_FM25640(0, 10);
//	write_TM_oper();
	_CLI();
	clean_screen();
	write_end_oper();
	_SEI();

INI_3:
    out();
}
//*****************************************************************************************
/*void write_TM_manag(void)
{
	static unsigned char a;
	for (a = 0; a < 8; a ++){
	_WDR();
	_EEPUT(EE_AAD_MANAG + a, data_ROM[a]);
	}
}*/
//*****************************************************************************************
/*void write_TM_oper(void)
{
	static unsigned char a;
	for (a = 0; a < 8; a ++){
	_WDR();
	_EEPUT(EE_AAD_OPER + a, data_ROM[a]);
	}
}*/
//*****************************************************************************************
/*void read_TM_manag(void)
{
	static unsigned char a;
	for (a = 0; a < 8; a ++){
	_WDR();
	_EEGET(tm_manag[a], EE_AAD_MANAG + a);
	}
}*/
//*****************************************************************************************
/*void read_TM_oper(void)
{
	static unsigned char a;
	for (a = 0; a < 8; a ++){
	_WDR();
	_EEGET(tm_oper[a], EE_AAD_OPER + a);
	}
}*/
//*****************************************************************************************
