#ifndef _MAIN_H_
#define _MAIN_H_

// PORTB
#define CS_FM25640 0x09     //  0000 1001
#define OFF_FM25640 0x19;  	//  0001 1001
//-----------------------------------------------------------------------------------------
//   FM25640
#define WREN 0x06    	//  0000 0110
#define WRSR 0x01    	//  0000 0001
#define READ 0x03    	//  0000 0011
#define WRITE 0x02    	//  0000 0010
//-----------------------------------------------------------------------------------------
// PORTD
#define LIGHT_ON 0x10      	//  0001 0000
#define A0 0x20            	//  0010 0000
#define RD 0x40            	//  0100 0000
#define E 0x80             	//  1000 0000

// PORTG
#define RES_ON 0           	//  0000 0000
#define RES_OFF 0x04        //  0000 0100
#define E1 1               	//  0000 0001
#define E2 2               	//  0000 0010
//-----------------------------------------------------------------------------------------
//   
#define DISPLAY_ON 0x3F    	//  0011 1111
#define SET_PAGE 0xB8      	//  1011 1000
#define SET_ADDRESS 0x40   	//  0100 0000
#define START_LINE 0xC0    	//  1100 0000
//-----------------------------------------------------------------------------------------
//      EEPROM
#define EE_AAD_MANAG 0x0010

//      EEPROM
#define EE_AAD_OPER 0x0020
//-----------------------------------------------------------------------------------------
//    
#define NONE_MENU 0			//    

#define MENU_SET 1

#define CHANGE_DATE 2		//  ""

#define CHANGE_TIME 3		//  ""

#define WRITE_KEY 15

#define KEY_MANAG 19

#define KEY_OPER 20

#define KEYBOARD_DELAY 255
//-----------------------------------------------------------------------------------------
//    -  
#define WINTER 'W'
#define SUMMER 'S'
//      TWI
//         var  / FM25640
#define ERROR 0xEE

#define READ_ADDR 0xD1      //  1101 0001
#define WRITE_ADDR 0xD0     //  1101 0000

#define	ASM 0			//  0 -  write_byte   C,
						//  1 -  write_byte  
//*****************************************************************************************
//  
//*****************************************************************************************
//  functions_LCD.c -  
//*****************************************************************************************
#if !ASM
void write_byte(void);		//        C
#endif

#if ASM
//       
void write_byte(unsigned char byte, unsigned char left_right, unsigned char data_comm);
#endif

void write_comm_L(void);	//      
void write_comm_R(void);	//      
void write_data_L(void);	//      
void write_data_R(void);	//      

//      8    
void write_LCD(unsigned char simbol[]);

//   
void initial_LCD(void);
//   
void black_screen(void);
//   
void clean_screen(void);
//     
void picture(void);
//        
//   ( 0  7),
//         ( 0  7),
//         ( 0  7)
void display_position(unsigned char string, unsigned char font_reticle_L,
				   unsigned char font_reticle_R);
//*****************************************************************************************
//  functions_clock.c -  
//    DS1307   TWI
//*****************************************************************************************
//    -  
void tetrada_L(unsigned char code);

//    -  
void tetrada_H(unsigned char code);

//         
void indication_time(unsigned char hour, unsigned char min, unsigned char second);

//         
void indication_date(unsigned char day, unsigned char month, unsigned char year);

//     
void time_save(void);
void date_save(void);

//  
void date_change(unsigned char change);

//  
void time_change(unsigned char change);
//-----------------------------------------------------------------------------------------
//      DS1307   TWI
void clock(void);

//      TWI       
//   DS1307       12864
//      -  
void read_data_clock(void);

//     TWI     
//        DS1307
void write_date_clock(void);

//     TWI    
//         DS1307
void write_time_clock(void);

//     TWI      DS1307
void write_clock(void);
//*****************************************************************************************
//   
//*****************************************************************************************

static unsigned char second, min, hour, week, day, month, year;

static unsigned char second_save, min_save, hour_save, week_save,
						day_save, month_save, year_save;

//   -  
static unsigned char season;

//    ,  
//      
static unsigned char cursor_invert;
//*****************************************************************************************
//  functions_TWI.c -    TWI
//*****************************************************************************************
//   START
int start_twi(void);

//   REPEATED START
int rep_start(void);

void stop_twi(void);

//      
int sla_w(unsigned char write_addr);

//      
int sla_r(unsigned char read_addr);

//    ,   
//     (   ),
//       
int write_byte_twi(unsigned char write_data);

int read_byte_twi(void);
int last_byte_twi(void);
//*****************************************************************************************
//  functions_menu.c -    
//*****************************************************************************************
void menu_simbol(void);
void print_simbol(void);
void menu_date(void);
void menu_time(void);

void cursor_up(unsigned char page_beg, unsigned char page_end, unsigned char step);
void cursor_down(unsigned char page_beg, unsigned char page_end, unsigned char step);
void key_manag_oper(void);
void key_manag(void);
void key_oper(void);
void write_end_manag(void);
void write_end_oper(void);
void key_1(void);
void key_2(void);
//*****************************************************************************************
//  interrupt.c -  
//*****************************************************************************************
//  functions_service.c -  
//*****************************************************************************************
//  
void delay_c(unsigned char delay);

//  
void delay_mc(unsigned char delay);

void BCD(unsigned char byte_bcd);

void write_FM25640(unsigned char addr_H, unsigned char addr_L);

void read_FM25640(unsigned char addr_H, unsigned char addr_L);
//*****************************************************************************************
//  functions_TM.c -    Touch Memory
//*****************************************************************************************
void inp(void);
void out(void);
void ROM_33(void);
void rd_data_ROM(void);
int calc_CRC(void);
void chec_data_TM(void);
void TM_line(void);
void TM_write_manag(void);
void TM_write_oper(void);
void write_TM_manag(void);
void write_TM_oper(void);
void read_TM_manag(void);
void read_TM_oper(void);
//*****************************************************************************************
//   
//*****************************************************************************************
unsigned char msucsr;       	//  MSUCSR  

//    
unsigned char byte;

//       
unsigned char left_right;

// ,     -   
unsigned char data_comm;

//  
static unsigned int col;

//   (     )
//       ( 0  7),
//   64  ( 0  63)
static int page_lcd;

//  ,  
static unsigned char key_simb;

//   ,       
static unsigned char  menu_flag;

//       (    0  7)
static unsigned char  cursor_flag;

//  
static unsigned char p = 0;

static unsigned char second, min, hour, week, day, month, year;
static unsigned char second_save, min_save, hour_save, week_save,
								day_save, month_save, year_save;

//   -  
static unsigned char season;

//     
//       ( 0  7),
//   128  ( 0  63     
//  64  127    )
static unsigned char column, column_1, string;

//        
static unsigned char inwert;

static unsigned char ten, one;

//    ,  
//      
static unsigned char cursor_invert;
//-----------------------------------------------------------------------------------------
//   
static unsigned char touch = 0;

//    (1)    (2)
static unsigned char chec_TM = 0;
//-----------------------------------------------------------------------------------------
unsigned char *p_b;		//   

// ,   
static unsigned char data_ROM[8] = {0, 0, 0, 0, 0, 0, 0, 0};

static unsigned char tm_manag[8];	//  

static unsigned char tm_oper[8];	//  
//*****************************************************************************************
//  beep.s -       
//*****************************************************************************************
void beep(void);	//       
//*****************************************************************************************
//  Alarm.s -       
//*****************************************************************************************
void alarm(unsigned char numb);	//       
//*****************************************************************************************
#include "Picture_data.c"
#include "Simbol_data.c"
#include "functions_LCD.c"
#include "functions_clock.c"
#include "functions_TWI.c"
#include "functions_service.c"
#include "functions_menu.c"
#include "interrupt.c"
#include "functions_TM.c"
//*****************************************************************************************
#endif
